export declare type LaunchConfiguration = GoLaunchConfiguration;
export interface BaseLaunchConfiguration {
    name: string;
    type: string;
    request: 'launch' | 'attach';
}
export interface GoLaunchConfiguration extends BaseLaunchConfiguration {
    type: 'go';
    request: 'launch';
    program: string;
    stopOnEntry?: boolean;
    args?: string[];
    showLog?: boolean;
    cwd?: string;
    env?: {
        [key: string]: string;
    };
    mode?: string;
    remotePath?: string;
    port?: number;
    host?: string;
    buildFlags?: string;
    init?: string;
    trace?: boolean | 'verbose';
    /** Optional path to .env file. */
    envFile?: string;
    backend?: string;
}
export interface CompoundConfiguration {
    name: string;
    configurations: string[];
}
export interface LaunchJson {
    version: string;
    configurations: LaunchConfiguration[];
    compounds: CompoundConfiguration[];
}
export declare function readLaunchJson(path: string): Promise<LaunchJson>;
export declare function expandCompound(launchJson: LaunchJson, name: string): LaunchConfiguration[];
export declare function launch(configs: LaunchConfiguration[]): Promise<void>;
