"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const onExit = require("exit-hook");
const leftPad = require("left-pad");
const child_process_1 = require("mz/child_process");
const fs_1 = require("mz/fs");
const stripJsonComments = require("strip-json-comments");
function expandVariables(value) {
    if (typeof value === 'string') {
        return value
            .replace(/\$\{workspaceRoot\}/g, process.cwd())
            .replace(/\$\{env\.(\w+)\}/g, (match, varName) => process.env[varName] || '');
    }
    if (typeof value === 'object' && value !== null) {
        for (const key of (Array.isArray(value) ? value.keys() : Object.keys(value))) {
            value[key] = expandVariables(value[key]);
        }
    }
    return value;
}
function readLaunchJson(path) {
    return __awaiter(this, void 0, void 0, function* () {
        const content = yield fs_1.readFile(path, 'utf-8');
        const json = stripJsonComments(content);
        return JSON.parse(json);
    });
}
exports.readLaunchJson = readLaunchJson;
const COLORS = [
    chalk.magenta,
    chalk.blue,
    chalk.cyan,
    chalk.green,
    chalk.yellow,
    chalk.red
];
function expandCompound(launchJson, name) {
    const config = launchJson.configurations.find(c => c.name === name);
    if (config) {
        return [config];
    }
    const compoundConfig = launchJson.compounds.find(c => c.name === name);
    if (compoundConfig) {
        return compoundConfig.configurations.reduce((configs, child) => configs.concat(expandCompound(launchJson, child)), []);
    }
    return [];
}
exports.expandCompound = expandCompound;
function launch(configs) {
    return __awaiter(this, void 0, void 0, function* () {
        configs = expandVariables(configs);
        const nameWidth = Math.max(...configs.map(config => config.name.length)) + 1;
        for (const config of configs) {
            switch (config.type) {
                case 'go': {
                    if (config.request !== 'launch') {
                        continue;
                    }
                    const color = COLORS[Math.floor(Math.random() * COLORS.length)];
                    const cp = child_process_1.spawn('go', ['run', config.program, ...(config.args || [])], {
                        cwd: config.cwd,
                        env: Object.assign({}, process.env, config.env)
                    });
                    onExit(() => {
                        cp.kill();
                    });
                    for (const fd of ['stdout', 'stderr']) {
                        cp[fd].on('data', chunk => {
                            const lines = chunk.toString().split('\n').map(line => color(new Date().toLocaleTimeString() + leftPad(config.name, nameWidth, ' ') + ' | ') + line);
                            process[fd].write(lines.join('\n') + '\n');
                        });
                    }
                }
            }
        }
    });
}
exports.launch = launch;
//# sourceMappingURL=launch.js.map